{% extends "allauth_ens/block-messages-base.html" %}

{% block messages-container %}
  {% if messages %}{{ block.super }}{% endif %}
{% endblock %}

{% block message-list %}

{% for message in messages %}
<li class="message {{ message.level_tag }}">
    {{ message }}
</li>
{% endfor %}

{% endblock %}
