{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Signup" %}{% endblock %}
{% block header-title %}{% trans "Signup" %}{% endblock %}

{% block content %}

<section>
  <ul class="actions">
    <li>
      <a href="{{ login_url }}">{% trans "Already have an account?" %}</a>
    </li>
  </ul>
  <form action="{% url "account_signup" %}" method="post">
    {% include "allauth_ens/block-form.html" with form=form %}
    <input type="submit" value="{% trans "Sign Up" %}">
    {% if redirect_field_value %}
    <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}">
    {% endif %}
  </form>
</section>

{% endblock %}
