{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Change Password" %}{% endblock %}
{% block header-title %}{% trans "Change Password" %}{% endblock %}

{% block messages-extra %}

{% include "allauth_ens/block-messages-form-errors.html" with form_errors=form.non_field_errors %}

{% endblock %}

{% block content %}

<section>
  <form action="{% url "account_change_password" %}" method="post">
    {% include "allauth_ens/block-form.html" with form=form submit_value=submit_value %}
    <input type="submit" value="{% trans "Change Password" %}">
  </form>
</section>

{% endblock %}
