{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Password Reset" %}{% endblock %}
{% block header-title %}{% trans "Password Reset" %}{% endblock %}

{% block content %}

<section>
  <p>
    {% blocktrans %}
    Forgotten your password? Enter your e-mail address below, and we'll send
    you an e-mail allowing you to reset it.
    {% endblocktrans %}
  </p>
  <form action="{% url "account_reset_password" %}" method="post">
    {% include "allauth_ens/block-form.html" with form=form %}
    <input type="submit" value="{% trans "Reset Password" %}">
  </form>
</section>

{% endblock %}
