{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Login Cancelled" %}{% endblock %}
{% block header-title %}{% trans "Login Cancelled" %}{% endblock %}

{% block content %}

<section>
  <p>
    {% url "account_login" as login_url %}

    {% blocktrans %}
    You decided to cancel logging into our site using one of your existing accounts. If this was a mistake, please proceed to <a href="{{login_url}}">sign in</a>.{% endblocktrans %}
    {% endblocktrans %}
  </p>
</section>

{% endblock %}
