{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Change Password" %}{% endblock %}
{% block header-title %}{% trans "Change Password" %}{% endblock %}

{% block content %}

<section>
  {% if token_fail %}
    <p>
      {% url 'account_reset_password' as passwd_reset_url %}
      {% blocktrans %}
      The password reset link was invalid, possibly because it has already been used.
      Please request a <a href="{{ passwd_reset_url }}">new password reset</a>.
      {% endblocktrans %}
    </p>
  {% elif form %}
    <form action="" method="post">
      {% include "allauth_ens/block-form.html" with form=form %}
      <input type="submit" value="{% trans "Reset Password" %}">
    </form>
  {% else %}
    <p>{% trans "Your password is now changed." %}</p>
  {% endif %}
</section>

{% endblock %}
